@@ -8,14 +8,11 @@ from .core import (
     Predicate,
     is_type,
     no_error,
-    INT_STR,
-    FLOAT_STR,
-    NUM_STR,
     values_for_key,
     max_depth,
 )
 
-__version__ = "0.13.1"
+__version__ = "0.14.0"
 
 __all__ = (
     "__version__",
@@ -23,9 +20,6 @@ __all__ = (
     "Predicate",
     "is_type",
     "no_error",
-    "INT_STR",
-    "FLOAT_STR",
-    "NUM_STR",
     "values_for_key",
     "max_depth",
 )
